@@ -46,10 +46,10 @@
 
 from collections.abc import Mapping
 from datetime import date, datetime
-import io
 import json
 import logging
 import os
+import pathlib
 import pkg_resources
 import re
 from typing import IO, Union
@@ -68,7 +68,7 @@ from pygeometa.schemas import get_supported_schemas, load_schema
 
 LOGGER = logging.getLogger(__name__)
 
-SCHEMAS = f'{os.path.dirname(os.path.realpath(__file__))}{os.sep}schemas'
+SCHEMAS = pathlib.Path(__file__).resolve().parent / 'schemas'
 
 VERSION = pkg_resources.require('pygeometa')[0].version
 
@@ -241,12 +241,16 @@ def read_mcf(mcf: Union[dict, str]) -> dict:
                 LOGGER.debug('mcf object is already a dict')
                 LOGGER.debug('Environment variables will NOT be interpreted')
                 dict_ = mcf_object
+            elif isinstance(mcf_object, pathlib.PurePath):
+                LOGGER.debug('mcf object is a pathlib.PurePath')
+                with mcf_object.open() as fh:
+                    dict_ = yaml_load(fh)
             elif 'metadata:' in mcf_object:
                 LOGGER.debug('mcf object is a string')
                 dict_ = yaml_load(mcf_object)
             else:
                 LOGGER.debug('mcf object is likely a filepath')
-                with io.open(mcf_object, encoding='utf-8') as fh:
+                with open(mcf_object, encoding='utf-8') as fh:
                     dict_ = yaml_load(fh)
         except yaml.scanner.ScannerError as err:
             msg = f'YAML parsing error: {err}'
@@ -389,15 +393,15 @@ def validate_mcf(instance_dict: dict) -> bool:
     :returns: `bool` of validation
     """
 
-    schema_file = os.path.join(SCHEMAS, 'mcf', 'core.yaml')
+    schema_file = SCHEMAS / 'mcf' / 'core.yaml'
 
-    with open(schema_file) as fh2:
+    with schema_file.open() as fh2:
         schema_dict = yaml_load(fh2)
 
         try:
             jsonschema_validate(instance_dict, schema_dict)
         except ValidationError as err:
-            raise MCFValidationError(err)
+            raise MCFValidationError(repr(err))
 
         return True
 
@@ -405,8 +409,9 @@ def validate_mcf(instance_dict: dict) -> bool:
 def get_abspath(mcf, filepath):
     """helper function absolute file access"""
 
-    abspath = os.path.dirname(os.path.realpath(mcf))
-    return os.path.join(abspath, filepath)
+    abspath = pathlib.Path(mcf).resolve().parent
+
+    return abspath / filepath
 
 
 def get_typed_value(value) -> Union[float, int, str]:
@@ -485,9 +490,7 @@ def import_(ctx, metadata_file, schema, output, verbosity):
     try:
         content = schema_object.import_(metadata_file.read())
     except NotImplementedError:
-        raise click.ClickException(f'Import not support for {schema}')
-    except NotImplementedError as err:
-        raise click.ClickException(err)
+        raise click.ClickException(f'Import not supported for {schema}')
 
     if output is None:
         click.echo(yaml.dump(content))
@@ -562,7 +565,7 @@ def schemas(ctx, verbosity):
 @cli_options.ARGUMENT_MCF
 @cli_options.OPTION_VERBOSITY
 def validate(ctx, mcf, verbosity):
-    """Validate MCF Document"""
+    """validate MCF Document"""
 
     click.echo(f'Validating {mcf}')
 
@@ -570,3 +573,37 @@ def validate(ctx, mcf, verbosity):
     validate_mcf(instance)
 
     click.echo('Valid MCF document')
+
+
+@click.command()
+@click.pass_context
+@cli_options.ARGUMENT_METADATA_FILE
+@cli_options.OPTION_OUTPUT
+@cli_options.OPTION_VERBOSITY
+@click.option('--input-schema', required=True,
+              type=click.Choice(get_supported_schemas()),
+              help='Metadata schema of input file')
+@click.option('--output-schema', required=True,
+              type=click.Choice(get_supported_schemas()),
+              help='Metadata schema of input file')
+def transform(ctx, metadata_file, input_schema, output_schema, output,
+              verbosity):
+    """transform metadata"""
+
+    LOGGER.info(f'Importing {metadata_file} into {input_schema}')
+    schema_object_input = load_schema(input_schema)
+    content = None
+
+    try:
+        content = schema_object_input.import_(metadata_file.read())
+    except NotImplementedError:
+        raise click.ClickException(f'Import not supported for {input_schema}')
+
+    LOGGER.info(f'Processing into {output_schema}')
+    schema_object_output = load_schema(output_schema)
+    content = schema_object_output.write(content)
+
+    if output is None:
+        click.echo(content)
+    else:
+        output.write(content)
