@@ -45,6 +45,7 @@
 
 import json
 import os
+from typing import Union
 
 from pygeometa.core import get_charstring
 from pygeometa.helpers import json_serial
@@ -65,13 +66,15 @@ class STACItemOutputSchema(BaseOutputSchema):
 
         super().__init__('stac-item', 'json', THISDIR)
 
-    def write(self, mcf: dict) -> str:
+    def write(self, mcf: dict, stringify: str = True) -> Union[dict, str]:
         """
-        Write outputschema to JSON string buffer
+        Write MCF to STAC Item
 
         :param mcf: dict of MCF content model
+        :param stringify: whether to return a string representation (default)
+                          else native (dict, etree)
 
-        :returns: MCF as a STAC item representation
+        :returns: `dict` or `str` of MCF as a STAC item
         """
 
         lang1 = mcf['metadata'].get('language')
@@ -130,4 +133,7 @@ class STACItemOutputSchema(BaseOutputSchema):
             }
             stac_item['links'].append(link)
 
-        return json.dumps(stac_item, default=json_serial, indent=4)
+        if stringify:
+            return json.dumps(stac_item, default=json_serial, indent=4)
+
+        return stac_item
